
# Slot: in code system




URI: [ks:in_code_system](https://w3id.org/linkml/tests/kitchen_sink/in_code_system)


## Domain and Range

None &#8594;  <sub>0..1</sub> [CodeSystem](CodeSystem.md)

## Parents


## Children


## Used by

 * [Concept](Concept.md)
 * [DiagnosisConcept](DiagnosisConcept.md)
 * [ProcedureConcept](ProcedureConcept.md)
